==> nextcloud-25.0.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/ja.js <==
OC.L10N.register(
    "circles",
    {
    "Circles" : "サークル",
    "Circles' files" : "サークルのファイル",
    "Select circles to filter by" : "フィルタリングするサークルを選択",
    "No circles found" : "サークルが見つかりません",
    "Please select circles to filter by" : "フィルタリングするサークルを選択してください",
    "No files found for the selected circles" : "選択したサークルにファイルが見つかりません",
    "You created the circle {circle}" : "サークル {circle} を作成しました",
    "{author} created the circle {circle}" : "{author} が {circle} を作成しました",
    "You deleted {circle}" : "あなたは {circle} を削除しました",
    "{author} deleted {circle}" : "{author} が {circle} を削除しました",
    "You linked {group} to {circle}" : "{group}を{circle}にリンクしました",
    "{group} has been linked to {circle} by {author}" : "{group}は{author}によって{circle}にリンクされました",
    "You unlinked {group} from {circle}" : "{group}と{circle}のリンクを解除しました",
    "{group} has been unlinked from {circle} by {author}" : "{group}と{author}の{circle}のリンクが解除されました",
    "You changed the level of the linked group {group} in {circle} to %1$s" : "{circle}のリンクされたグループ{group}のレベルを %1$s に変更しました",
    "{author} changed the level of the linked group {group} in {circle} to %1$s" : "{author} {circle}のリンクされたグループ{group}のレベルを %1$s に変更しました",
    "You sent a request to link {circle} with {remote}" : "{circle}と{remote}とのリンクリクエストを送信しました。",
    "{author} sent a request to link {circle} with {remote}" : "{author}が{circle}と{remote}をリンクするリクエストを送信しました",
    "{remote} requested a link with {circle}" : "{リモート}が{サークル}とのリンクをリクエストしました",
    "The request to link {circle} with {remote} has been rejected" : "{circle}と{remote}をリンクするリクエストが拒否されました",
    "The request to link {remote} with {circle} has been canceled remotely" : "{remote}と{circle}をリンクするリクエストがリモートでキャンセルされました",
    "The request to link {circle} with {remote} has been accepted" : "{circle}と{remote}をリンクするリクエストが承認されました",
    "You dismissed the request to link {remote} with {circle}" : "{remote}と{circle}のリンクリクエストを却下しました。",
    "{author} dismissed the request to link {remote} with {circle}" : "{author}が{remote}と{circle}のリンクリクエストを却下しました",
    "You canceled the request to link {circle} with {remote}" : "{circle}と{remote}とのリンクリクエストをキャンセルしました",
    "{author} canceled the request to link {circle} with {remote}" : "{author}が{circle}と{remote}のリンクリクエストをキャンセルしました",
    "You accepted the request to link {remote} with {circle}" : "{リモート}と{サークル}のリンクリクエストを受け入れました。",
    "{author} accepted the request to link {remote} with {circle}" : "{author}が{remote}と{circle}のリンクリクエストを受け入れました",
    "A link between {circle} and {remote} is now up and running" : "{circle}と{remote}のリンクがアップされています",
    "The link between {circle} and {remote} has been shutdown remotely" : "{circle}と{remote}のリンクがリモートで停止しています",
    "You closed the link between {circle} and {remote}" : "{circle}と{remote}の間のリンクを閉じました",
    "{author} closed the link between {circle} and {remote}" : "{author}が{circle}と{remote}のリンクを閉じました",
    "You joined {circle}" : "あなたは {circle} に参加しました",
    "{member} joined {circle}" : "{member} が {circle} に参加しました",
    "You accepted the invitation to join {circle}" : "{circle}への招待を受け入れました",
    "{member} accepted the invitation to join {circle}" : "{member}が{circle}への招待を受け入れました",
    "You added {member} as member to {circle}" : "あなたは {member} を {circle} にメンバーとして追加しました",
    "You have been added as member to {circle} by {author}" : "{author}が{circle}にメンバーとして追加しました",
    "{member} has been added as member to {circle} by {author}" : "{author}によって{member}が{circle}のメンバーとして追加されました",
    "You added {external} to {circle}" : "{circle}に{external}を追加しました",
    "{external} has been added to {circle} by {author}" : "{external} が {author} によって {circle} に追加されました",
    "You accepted {member}'s request to join {circle}" : "{member} の {circle} への参加リクエストを受け入れました",
    "Your request to join {circle} has been accepted by {author}" : "あなたの {circle} への参加リクエストは {author} によって承認されました",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} の {circle} への参加リクエストが{author}に受け入れられました",
    "You left {circle}" : "あなたは {circle} を抜けました",
    "{member} left {circle}" : "{member} が {circle} を抜けました",
    "You declined the invitation to join {circle}" : "{circle}への招待を辞退しました",
    "{member} declined an invitation to join {circle}" : "{member}さんが{circle}への招待を辞退しました",
    "You cancelled your request to join {circle}" : "{circle}への参加リクエストをキャンセルしました。",
    "{member} cancelled his request to join {circle}" : "{member}さんが{circle}への参加リクエストをキャンセルしました",
    "You removed {member} from {circle}" : "あなたは {member} を {circle} から除名しました",
    "You have been removed from {circle} by {author}" : "{author}が{circle}からあなたを削除しました",
    "{member} has been removed from {circle} by {author}" : "{author}によって{member}が{circle}から削除されました",
    "You removed {external} from {circle}" : "{circle}から{external}を削除しました",
    "{external} has been removed from {circle} by {author}" : "{external} が {author} によって {circle} から削除されました",
    "You cancelled {member}'s invitation to join {circle}" : "{member} の {circle} への招待状をキャンセルしました",
    "Your invitation to join {circle} has been cancelled by {author}" : "{circle}への招待状が{author}によってキャンセルされました",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} {member}の{circle}への招待状をキャンセルしました",
    "You dismissed {member}'s request to join {circle}" : "{member}の{circle}への参加リクエストを却下しました",
    "Your request to join {circle} has been dismissed by {author}" : "{circle}に参加するあなたのリクエストは{author}によって却下されました",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} の {circle} への参加リクエストが {author} によって却下されました",
    "You invited {member} to join {circle}" : "{member} に {circle} に参加するように招待しました",
    "You have been invited to join {circle} by {author}" : "{author}が{circle}に参加するように招待されました",
    "{member} has been invited to join {circle} by {author}" : "{author} によって {member} が {circle} に参加するよう招待されました",
    "You changed {member}'s level in {circle} to %1$s" : "{circle}の{member}のレベルを %1$s に変更しました",
    "{author} changed your level in {circle} to %1$s" : "{author}が{circle}のレベルを %1$s に変更しました",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} が{member}{circle} のレベルを %1$s に変更しました",
    "You sent a request to join {circle}" : "{circle}への参加リクエストを送信しました。",
    "{member} sent a request to join {circle}" : "{member}が{circle}への参加リクエストを送信しました",
    "You are the new owner of {circle}" : "あなたは {circle} の新しいオーナーです",
    "{member} is the new owner of {circle}" : "{member} は {circle} の新しいオーナーです",
    "On events happening in a <strong>Circle</strong> of which you are a member" : "あなたがメンバーである<strong>サークル</strong> で発生するイベントに応じて",
    "Any important event in a <strong>Circle</strong> you are moderating" : "あなたがモデレートしている <strong>Circle</strong> の重要なイベント",
    "On global events happening in any <strong>Circle</strong>" : "いずれかの<strong>Circle</strong>で発生するグローバルなイベントに対応して",
    "Single" : "シングル",
    "Personal" : "パーソナル",
    "System" : "システム",
    "Visible" : "表示する",
    "Open" : "開く",
    "Invite" : "招待状",
    "Join Request" : "参加要求",
    "Friends" : "お友達",
    "Password Protected" : "パスワードによる保護",
    "No Owner" : "オーナーがいません",
    "Hidden" : "非公開",
    "Backend" : "バックエンド",
    "Local" : "ローカル",
    "Root" : "ルート",
    "Circle Invite" : "サークル招待",
    "Federated" : "連携",
    "Mount point" : "マウントポイント",
    "Nextcloud Group" : "Nextcloudグループ",
    "Email Address" : "電子メールアドレス",
    "Contact" : "連絡先",
    "Circle" : "サークル",
    "Nextcloud App" : "Nextcloudアプリ",
    "Member" : "メンバー",
    "Moderator" : "モデレータ",
    "Admin" : "管理者",
    "Owner" : "オーナー",
    "%s shared »%s« with you." : "%sが あなたと »%s«を共有しました",
    "%s shared »%s« with \"%s\"." : "%sが»%s«を\"%s\"と共有しました。",
    "%s on %s" : "%s に %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sが»%2$s«をあなたと共有しました。\nそれにアクセスするためのリンクが既にEメールで届いているはずです。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$sさんがあなたと»%2$s«を共有しました。アクセス用のリンクを記載したメールが、既に届いているはずです。",
    "Password to access »%1$s« shared to you by %2$s" : "»%1$s«への共有アクセスのパスワードが %2$s から共有されました",
    "Password to access »%s«" : "»%s« にアクセスするパスワード",
    "It is protected with the following password:" : "次のパスワードで保護されています。",
    "%1$s via %2$s" : "%1$sに%2$sから",
    "Click the button below to open it." : "下のボタンをクリックして開きます。",
    "Open »%s«" : "»%s«を開く",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$sさんがあなたと複数のファイルを共有しました。\nアクセス用のリンクを記載したメールが、既に届いているはずです。\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sさんがあなたと複数のファイルを共有しました。アクセス用のリンクを記載したメールが、既に届いているはずです。",
    "Password to access files shared to you by %1$s" : "%1$sによって共有されたファイルにアクセスするためのパスワード",
    "Password to access files" : "ファイルアクセスのパスワード",
    "%s shared multiple files with \"%s\"." : "%sが\"%s\"と複数のファイルを共有しました。",
    "%s shared multiple files with you." : "%sがあなたと複数のファイルを共有しました。",
    "Boot up" : "起動時",
    "Initialisation Nextcloud" : "初期設定 Nextcloud",
    "Initialisation Circles App" : "初期化サークルアプリ",
    "Fresh installation status" : "フレッシュインストールの状況",
    "Building Local Database" : "ローカルデータベースの構築",
    "Testing Basic Circle Creation" : "基本的なサークル作成のテスト",
    "Adding local users and moderators" : "ローカルユーザーとモデレーターを追加する",
    "Circle not found" : "サークルが見つかりません",
    "Circle not found " : "サークルが見つかりません",
    "A circle with that name exists" : "その名前のサークルが存在します",
    "You cannot use the Circles Application until your administrator has allowed at least one type of circles" : "管理者が少なくとも1種類のサークルを許可するまで、サークルアプリケーションを使用することはできません",
    "This member does not exist" : "このメンバーは存在しません",
    "Federated link not found" : "フェデレーションリンクが見つかりません",
    "This feature is not available for personal circles" : "この機能は個人のサークルでは使用できません",
    "The circle is not federated" : "サークルは統合されていません",
    "You cannot join this circle" : "あなたはこのサークルに加入できません",
    "This member is not a moderator" : "このメンバーはモデレーターではありません",
    "Insufficient privileges" : "権限が不十分です",
    "This member is the owner of the circle" : "このメンバーはサークルのオーナーです",
    "Level cannot be changed for this type of member" : "このタイプのメンバーのレベルを変更することはできません",
    "You are already a member of this circle" : "あなたはすでにこのサークルのメンバーです",
    "You have been blocked from this circle" : "あなたはこのサークルからブロックされています",
    "%s (Circle owned by %s)" : "%s (%sが所有するサークル)",
    "You are now a member of the Circle \"%2$s\"" : "あなたはサークル「%2$s」のメンバーではありません",
    "You have been invited by %1$s into the Circle \"%2$s\"" : "あなたは%1$sからサークル「%2$s」に招待されています",
    "%1$s sent a request to be a member of the Circle \"%2$s\"" : "%1$sがサークル「%2$s」のメンバー申請を送りました",
    "Accept" : "承諾",
    "Refuse" : "拒否する",
    "Leave the circle" : "サークルを退会する",
    "%s" : "%s",
    "Personal Circle" : "パーソナルサークル",
    "%s owned by %s" : "%s%sが所有",
    "You need a specify a type of circle" : "あなたはサークルのタイプを指定する必要があります",
    "This member is not the owner of the circle" : "このメンバーはサークルのオーナーではありません",
    "This member is not an admin of the circle" : "このメンバーはサークルの管理者ではありません",
    "Group contains too many members" : "グループに含まれるメンバー数が多すぎます",
    "This group does not exist" : "このグループは存在しません",
    "This group is already linked to the circle" : "このグループはすでにサークルにリンクしています",
    "You cannot edit level in a personal circle" : "あなたは個人的なサークルのレベルを編集することはできません",
    "Group cannot be set as owner of a circle" : "グループをサークルのオーナーとして設定することはできません",
    "now" : "今",
    "Email format is not valid" : "メールフォーマットが有効ではありません",
    "This contact is not available" : "この連絡先は利用できません",
    "You have no permission to create a new circle" : "新しいサークルを作成する権限がありません",
    "%s shared a file with \"%s\"." : "%sは\"%s\"どファイルを共有しました。",
    "%s shared a file with you." : "%sはあなたとファイルを共有しました。",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s は、いくつかのコンテンツをあなたと共有しました。\nすでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s は、いくつかのコンテンツをあなたと共有しました。すでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。",
    "Password to access content shared with you by %1$s" : "%1$sが共有するコンテンツにアクセスするためのパスワード。",
    "Password to access content" : "コンテンツにアクセスするためのパスワード",
    "This item is already shared with this circle" : "このアイテムは既にこのサークルで共有されています",
    "Could not find share" : "シェアを見つけることができませんでした",
    "Bring cloud-users closer together." : "クラウドユーザー同士を近づける。",
    "No files in here" : "ファイルがありません",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "Nextcloud User" : "Nextcloudユーザー",
    "This user is already a member of the circle" : "このユーザーはすでにサークルのメンバーです",
    "The user is already a member of this circle" : "ユーザーはすでにこのサークルのメンバーです",
    "The user has already been invited into this circle" : "ユーザーはすでにこのサークルに招待されています",
    "This user does not exist" : "このユーザーは存在しません",
    "Circles allows your users to create their own groups of users/colleagues/friends.\nThose groups of users (or \"circles\") can then be used by any other app for sharing purpose." : "Circlesではユーザーや同僚、友人のグループを自由に作ることができます。\nこのユーザーグループ (サークル) は、何かを共有する目的で、様々なアプリから使用されます。"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.7-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/circles/l10n/ja.js <==
OC.L10N.register(
    "circles",
    {
    "Teams" : "チーム",
    "You created the team {circle}" : "あなたはチーム {circle} を作成しました",
    "{author} created the team {circle}" : "{author} がチーム {circle} を作成しました",
    "You deleted {circle}" : "あなたは {circle} を削除しました",
    "{author} deleted {circle}" : "{author} が {circle} を削除しました",
    "You made {member} join {circle}" : "あなたは {member} を {circle} に加入させました",
    "{author} made {member} join {circle}" : "{author} は {member} を {circle} に加入させました",
    "You added team {member} as member to {circle}" : "あなたは {circle} にチーム {member} をメンバーとして追加しました",
    "{author} added team {member} as member to {circle}" : "{author}がチーム{member}を{circle}のメンバーとして追加しました",
    "You made {member} leave {circle}" : "あなたは {member} を {circle} から脱退させました",
    "{author} made {member} leave {circle}" : "{author} が {member} を {circle} から脱退させました",
    "You removed {member} from {circle}" : "あなたは {member} を {circle} から除名しました",
    "{author} removed {member} from {circle}" : "{author}が{circle}から{member}を削除しました",
    "You joined {circle}" : "あなたは {circle} に参加しました",
    "{member} joined {circle}" : "{member} が {circle} に参加しました",
    "You accepted the invitation to join {circle}" : "{circle}への招待を受け入れました",
    "{member} accepted the invitation to join {circle}" : "{member}が{circle}への招待を受け入れました",
    "You added {member} as member to {circle}" : "あなたは {member} を {circle} にメンバーとして追加しました",
    "You have been added as member to {circle} by {author}" : "{author}が{circle}にメンバーとして追加しました",
    "{member} has been added as member to {circle} by {author}" : "{author}によって{member}が{circle}のメンバーとして追加されました",
    "You added {external} to {circle}" : "{circle}に{external}を追加しました",
    "{external} has been added to {circle} by {author}" : "{external} が {author} によって {circle} に追加されました",
    "You accepted {member}'s request to join {circle}" : "{member} の {circle} への参加リクエストを受け入れました",
    "Your request to join {circle} has been accepted by {author}" : "あなたの {circle} への参加リクエストは {author} によって承認されました",
    "{member}'s request to join {circle} has been accepted by {author}" : "{member} の {circle} への参加リクエストが{author}に受け入れられました",
    "You left {circle}" : "あなたは {circle} を抜けました",
    "{member} left {circle}" : "{member} が {circle} を抜けました",
    "You declined the invitation to join {circle}" : "{circle}への招待を辞退しました",
    "{member} declined an invitation to join {circle}" : "{member}さんが{circle}への招待を辞退しました",
    "You cancelled your request to join {circle}" : "{circle}への参加リクエストをキャンセルしました。",
    "{member} cancelled a request to join {circle}" : "{member} が {circle} への加入申請を取り消しました",
    "You have been removed from {circle} by {author}" : "{author}が{circle}からあなたを削除しました",
    "{member} has been removed from {circle} by {author}" : "{author}によって{member}が{circle}から削除されました",
    "You removed {external} from {circle}" : "{circle}から{external}を削除しました",
    "{external} has been removed from {circle} by {author}" : "{external} が {author} によって {circle} から削除されました",
    "You cancelled {member}'s invitation to join {circle}" : "{member} の {circle} への招待状をキャンセルしました",
    "Your invitation to join {circle} has been cancelled by {author}" : "{circle}への招待状が{author}によってキャンセルされました",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} {member}の{circle}への招待状をキャンセルしました",
    "You dismissed {member}'s request to join {circle}" : "{member}の{circle}への参加リクエストを却下しました",
    "Your request to join {circle} has been dismissed by {author}" : "{circle}に参加するあなたのリクエストは{author}によって却下されました",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{member} の {circle} への参加リクエストが {author} によって却下されました",
    "You invited {member} to join {circle}" : "{member} に {circle} に参加するように招待しました",
    "You have been invited to join {circle} by {author}" : "{author}が{circle}に参加するように招待されました",
    "{member} has been invited to join {circle} by {author}" : "{author} によって {member} が {circle} に参加するよう招待されました",
    "You changed {member}'s level in {circle} to %1$s" : "{circle}の{member}のレベルを %1$s に変更しました",
    "{author} changed your level in {circle} to %1$s" : "{author}が{circle}のレベルを %1$s に変更しました",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} が{member}{circle} のレベルを %1$s に変更しました",
    "You sent a request to join {circle}" : "{circle}への参加リクエストを送信しました。",
    "{member} sent a request to join {circle}" : "{member}が{circle}への参加リクエストを送信しました",
    "You are the new owner of {circle}" : "あなたは {circle} の新しいオーナーです",
    "{member} is the new owner of {circle}" : "{member} は {circle} の新しいオーナーです",
    "On events happening in a <strong>team</strong> of which you are a member" : "あなたが所属する<strong>チーム</strong> で起きた出来事について",
    "Any important event in a <strong>team</strong> you are moderating" : "あなたがモデレーターを務める <strong>チーム</strong> の重要なイベント",
    "On global events happening in any <strong>team</strong>" : "どの<strong>チーム</strong>でも起きているグローバルな出来事について",
    "Single" : "シングル",
    "Personal" : "パーソナル",
    "System" : "システム",
    "Visible" : "表示する",
    "Open" : "開く",
    "Invite" : "招待状",
    "Join request" : "参加リクエスト",
    "Friends" : "お友達",
    "Password protected" : "パスワード保護",
    "No Owner" : "オーナーがいません",
    "Hidden" : "非公開",
    "Backend" : "バックエンド",
    "Local" : "ローカル",
    "Root" : "ルート",
    "Team invite" : "チーム招待",
    "Federated" : "連携",
    "Mount point" : "マウントポイント",
    "Nextcloud Account" : "Nextcloud アカウント",
    "Nextcloud Group" : "Nextcloudグループ",
    "Email address" : "メールアドレス",
    "Contact" : "連絡先",
    "Circle" : "サークル",
    "Nextcloud App" : "Nextcloudアプリ",
    "Member" : "メンバー",
    "Moderator" : "モデレータ",
    "Admin" : "管理者",
    "Owner" : "オーナー",
    "%s shared »%s« with you." : "%sが あなたと »%s«を共有しました",
    "%s shared »%s« with \"%s\"." : "%sが»%s«を\"%s\"と共有しました。",
    "%s on %s" : "%s に %s",
    "%1$s shared »%2$s« with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$sが»%2$s«をあなたと共有しました。\nそれにアクセスするためのリンクが既にEメールで届いているはずです。\n",
    "%1$s shared »%2$s« with you. You should have already received a separate email with a link to access it." : "%1$sさんがあなたと»%2$s«を共有しました。アクセス用のリンクを記載したメールが、既に届いているはずです。",
    "Password to access »%1$s« shared to you by %2$s" : "»%1$s«への共有アクセスのパスワードが %2$s から共有されました",
    "Password to access »%s«" : "»%s« にアクセスするパスワード",
    "It is protected with the following password:" : "次のパスワードで保護されています。",
    "%1$s via %2$s" : "%1$sに%2$sから",
    "Click the button below to open it." : "下のボタンをクリックして開きます。",
    "Open »%s«" : "»%s«を開く",
    "%1$s shared multiple files with you.\nYou should have already received a separate email with a link to access them.\n" : "%1$sさんがあなたと複数のファイルを共有しました。\nアクセス用のリンクを記載したメールが、既に届いているはずです。\n",
    "%1$s shared multiple files with you. You should have already received a separate email with a link to access them." : "%1$sさんがあなたと複数のファイルを共有しました。アクセス用のリンクを記載したメールが、既に届いているはずです。",
    "Password to access files shared to you by %1$s" : "%1$sによって共有されたファイルにアクセスするためのパスワード",
    "Password to access files" : "ファイルアクセスのパスワード",
    "%s shared multiple files with \"%s\"." : "%sが\"%s\"と複数のファイルを共有しました。",
    "%s shared multiple files with you." : "%sがあなたと複数のファイルを共有しました。",
    "Boot up" : "起動時",
    "Nextcloud Initialization" : "Nextcloud初期化",
    "Circles App Initialization" : "Circleアプリの初期化",
    "Fresh installation status" : "フレッシュインストールの状況",
    "Building Local Database" : "ローカルデータベースの構築",
    "Testing Basic Circle Creation" : "基本的なサークル作成のテスト",
    "Adding local users and moderators" : "ローカルユーザーとモデレーターを追加する",
    "Show all teams" : "すべてのチームを表示",
    "Create a new team" : "新しいチームを作成する",
    "Files" : "ファイル",
    "This feature is not available for personal circles" : "この機能は個人のサークルでは使用できません",
    "The team is not federated" : "チームは統合されていません",
    "You cannot join this team" : "あなたはこのチームに参加できません",
    "This member is not a moderator" : "このメンバーはモデレーターではありません",
    "Insufficient privileges" : "権限が不十分です",
    "This member does not exist" : "このメンバーは存在しません",
    "This member is the owner of the team" : "このメンバーはチームのオーナーです",
    "Level cannot be changed for this type of member" : "このタイプのメンバーのレベルを変更することはできません",
    "You are already a member of this circle" : "あなたはすでにこのサークルのメンバーです",
    "You have been blocked from this circle" : "あなたはこのサークルからブロックされています",
    "The account is already a member of this circle" : "そのアカウントはすでにこのサークルのメンバーです",
    "The account has already been invited into this circle" : "アカウントはすでにこのサークルに招待されています",
    "%s (Team owned by %s)" : "%s (%s が所有するサークル)",
    "You are now a member of the Team \"%2$s\"" : "あなたはチーム \"%2$s\" のメンバーになりました",
    "You have been invited by %1$s into the Team \"%2$s\"" : "あなたは%1$sからチーム \"%2$s\"に招待されています",
    "%1$s sent a request to be a member of the Team \"%2$s\"" : "%1$sがチーム\"%2$s\"のメンバー申請を送りました",
    "Accept" : "承諾",
    "Refuse" : "拒否する",
    "Leave the team" : "チームを離脱",
    "%s" : "%s",
    "Personal team" : "パーソナルチーム",
    "%s owned by %s" : "%s%sが所有",
    "You have no permission to create a new team" : "新しいチームを作成する権限がありません",
    "%s shared a file with \"%s\"." : "%sは\"%s\"どファイルを共有しました。",
    "%s shared a file with you." : "%sはあなたとファイルを共有しました。",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s は、いくつかのコンテンツをあなたと共有しました。\nすでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s は、いくつかのコンテンツをあなたと共有しました。すでに、アクセスするためのリンクが記載された別の電子メールが届いているはずです。",
    "Password to access content shared with you by %1$s" : "%1$sが共有するコンテンツにアクセスするためのパスワード。",
    "Password to access content" : "コンテンツにアクセスするためのパスワード",
    "This item is already shared with this team" : "このアイテムは既にこのチームで共有されています",
    "Bring cloud-users closer together." : "クラウドユーザー同士を近づける。",
    "Teams allows people to create their own groups of people/colleagues/friends.\nThose groups of people can then be used by any other app for sharing purpose." : "チームを使って自分のグループ(同僚、友人)を作成することができます。\nこれらのグループは、他のアプリで共有先として使用することができます。",
    "No files in here" : "ファイルがありません",
    "No entries found in this folder" : "このフォルダーにはエントリーがありません",
    "Name" : "名前",
    "Size" : "サイズ",
    "Modified" : "更新日時",
    "Teams' files" : "チームのファイル",
    "Select team to filter by" : "フィルターするチームを選択",
    "No teams found" : "チームは見つかりませんでした",
    "Please select teams to filter by" : "フィルターするチームを選択してください",
    "No files found for the selected teams" : "選択したチームに割りあてられているファイルはありません",
    "Shared to Circles" : "サークルと共有"
},
"nplurals=1; plural=0;");
